@@ -1,13 +1,13 @@
 #ifndef AONLICENSEWINDOW_H
 #define AONLICENSEWINDOW_H
 
-#include <QDialog>
+#include "controls/dialogwindow.h"
 
 namespace Ui {
     class AonLicenseWindow;
 }
 
-class AonLicenseWindow : public QDialog
+class AonLicenseWindow : public DialogWindow
 {
     Q_OBJECT
 
