@@ -282,7 +282,7 @@ BookWindow::BookWindow(QWidget *parent) :
     qScriptRegisterSequenceMetaType< QList<Armor*> >(&m_Engine);
 }
 
-void BookWindow::Init()
+bool BookWindow::Init()
 {
     QSettings settings;
     if (QFile::exists(settings.fileName())){
@@ -293,13 +293,14 @@ void BookWindow::Init()
             msgBox.setIcon(QMessageBox::Warning);
             msgBox.setText("Error loading last saved position.");
             msgBox.exec();
-            return;
+            return false;
         }
     }
 
     QScriptValue objectValue = m_Engine.newQObject(m_Player);
     m_Engine.globalObject().setProperty("Player", objectValue);
     //ShowSection(m_Section != NULL ? m_Section->Number : 0);
+    return true;
 }
 
 BookWindow::~BookWindow()
