@@ -25,7 +25,7 @@ public:
     ~BookWindow();
 
     void Save(QString filename, Player* player, int book, int section);
-    void Init();
+    bool Init();
     static QString GetBookSaveFilename(int number);
 
 private:
