@@ -105,9 +105,13 @@ public:
 public slots:
     /** Returns the choice with the given index*/
     Choice* GetChoice(int);
-    /** Returns the weapons in the section*/
+    /** Enables the choice with the given index*/
+    void EnableChoice(int);
+    /** Disables the choice with the given index*/
+    void DisableChoice(int);
+    /** Returns the number of weapons in the section*/
     int GetWeaponsCount();
-    /** Returns the enemies in the section*/
+    /** Returns the number of enemies in the section*/
     int GetEnemiesCount();
     /** Removes enemies from the section*/
     void RemoveEnemies();
