@@ -41,6 +41,8 @@ public:
     bool IsUsable() { return GetIsMeal() || GetEnduranceRestore() || GetCombatskillDelta(); }
     void Use(QScriptEngine* engine, QScriptValue* functions);
 
+    QList<int> GetWeaponClasses();
+
 public slots:
     /** Returns the item name */
     QString GetName() { return Name; }
@@ -107,6 +109,8 @@ public slots:
     int GetSize() { return GetProperty("Size").toInt(); }
     /** Sets the item size (space used in the backpack) */
     void SetSize(int value) { SetProperty("Size", QString::number(value)); }
+    /** Returns the total item size (space used in the backpack) */
+    int GetTotalSize();
 
     /** Returns true if the item is equipped */
     bool GetIsEquipped() { return GetBoolProperty("IsEquipped"); }
@@ -127,6 +131,16 @@ public slots:
     /** Sets if the item is a weapon*/
     void SetIsWeapon(bool value) { SetBoolProperty("IsWeapon", value); }
 
+    /** Adds a weapon class */
+    void AddWeaponClass(int iClass);
+    /** Adds a weapon class */
+    void AddWeaponClass(QString value);
+
+    /** Returns true if the item has the given weapon class*/
+    bool HasWeaponClass(int value);
+    /** Returns true if the item has the given weapon class*/
+    bool HasWeaponClass(QString value);
+
     /** Returns true if the item can be equipped */
     bool GetCanBeEquipped();
     /** Sets if the item can be equipped */
@@ -144,14 +158,14 @@ public slots:
     /** Sets the armor class */
     void SetArmorClass(QString value);
 
-    /** Returns the hands needed to equip this item */
+    /** Returns the hands needed to equip the item */
     int GetHands() { return GetProperty("Hands").toInt(); }
-    /** Sets the hands needed to equip this item */
+    /** Sets the hands needed to equip the item */
     void SetHands(int value) { SetProperty("Hands", QString::number(value)); }
 
-    /** Returns the bonus this item gives when picking a random number */
+    /** Returns the bonus the item gives when picking a random number */
     int GetRandomBonus() { return GetProperty("RandomBonus").toInt(); }
-    /** Sets the bonus this item gives when picking a random number */
+    /** Sets the bonus the item gives when picking a random number */
     void SetRandomBonus(int value) { SetProperty("RandomBonus", QString::number(value)); }
 };
 
@@ -191,11 +205,13 @@ public slots:
     QList<int> Classes();
     /** Adds a weapon class */
     void AddClass(int iClass);
-    /** Returns true if this weapon has the given class*/
+    /** Adds a weapon class */
+    void AddClass(QString value);
+    /** Returns true if the weapon has the given class*/
     bool HasClass(QString value);
-    /** Returns true if this weapon has the given class*/
+    /** Returns true if the weapon has the given class*/
     bool HasClass(int value);
-    /** Returns the hands needed to equip this weapon */
+    /** Returns the hands needed to equip the weapon */
     int GetHands();
 
 };
@@ -217,7 +233,6 @@ public:
 /*!
 
 */
-
 class Armor : public Item
 {
     Q_OBJECT
@@ -242,7 +257,9 @@ public slots:
     int GetClass();
     /** Sets the armor class */
     void SetClass(int iClass);
-    /** Returns the hands needed to equip this armor */
+    /** Returns true if the armor has the given class*/
+    bool HasClass(QString value);
+    /** Returns the hands needed to equip the armor */
     int GetHands();
 };
 
