@@ -291,10 +291,6 @@ void Player::RemoveDiscipline(QString name)
 
 void Player::RemoveDisciplines()
 {
-    /*foreach (KaiDiscipline* d, KaiDisciplines)
-        delete d;
-    KaiDisciplines.clear();*/
-
     // Reset the discipline's serie to avoid counting them with GetDisciplineCount
     foreach (KaiDiscipline* d, KaiDisciplines)
         d->Serie = 0;
@@ -954,6 +950,14 @@ QString Player::GetProperty(QString name)
     return "";
 }
 
+int Player::GetIntProperty(QString name)
+{
+    QString p = GetProperty(name);
+    if (!p.isEmpty())
+        return p.toInt();
+    return 0;
+}
+
 void Player::SetProperty(QString name, QString value)
 {
     Properties[name] = value;
