@@ -75,6 +75,8 @@ public slots:
     void ClearProperties();
     /** Get a player property */
     QString GetProperty(QString name);
+    /** Get a integer player property */
+    int GetIntProperty(QString name);
     /** Set a player property */
     void SetProperty(QString name, QString value);
     /** Set a integer player property */
