@@ -3,6 +3,7 @@
 
 #include <QMainWindow>
 #include <QEventLoop>
+#include "controls/dialogwindow.h"
 #include "core/player.h"
 #include "randomnumberpicker.h"
 
@@ -10,7 +11,7 @@ namespace Ui {
     class PortholesWindow;
 }
 
-class PortholesWindow : public QMainWindow
+class PortholesWindow : public DialogWindow
 {
     Q_OBJECT
 
@@ -18,22 +19,15 @@ public:
     explicit PortholesWindow(QWidget *parent = 0, Player* player=0);
     ~PortholesWindow();
 
-    void exec();
-
-protected:
-    void closeEvent(QCloseEvent *event);
-
 private:
     Ui::PortholesWindow *ui;
 
-    bool m_CanClose;
     int m_CurrentPlayer;
     int m_Random1;
     int m_Random2;
     RandomNumberPicker* m_RandomPicker1;
     RandomNumberPicker* m_RandomPicker2;
     Player* m_Player;
-    QEventLoop* m_Loop;
 
     void UpdateData();
     void Play(int player);
