@@ -87,7 +87,7 @@ void StatusWindow::ShowData()
         ui->chkQuiver->setVisible(true);
         ui->lblArrowsD->setVisible(true);
         ui->lblArrows->setVisible(true);
-        ui->lblWeaponChecklist->setVisible(true);
+        ui->lblWeaponChecklist->setVisible(m_Player->HasDiscipline("Weaponmastery"));
         break;
     case Book::GrandMaster:
         ui->lblDisciplines->setText("Grand Master Disciplines:");
